pub trait InspectorRouteTableIdProvider<R> {
// Required method
fn route_table_id(id: &R) -> u32;
}Expand description
Provides an abstract interface for extracting inspect route table identifier.
Required Methods
Sourcefn route_table_id(id: &R) -> u32
fn route_table_id(id: &R) -> u32
Extracts the route table identifier from the provided opaque type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".